@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -32,8 +32,9 @@ class CControllerUserProfileEdit extends CControllerUserEditGeneral {
 
 		$fields = [
 			'change_password' =>	'in 1',
-			'password1' =>			'string',
-			'password2' =>			'string',
+			'current_password' =>	'password',
+			'password1' =>			'password',
+			'password2' =>			'password',
 			'lang' =>				'db users.lang|in '.implode(',', $locales),
 			'timezone' =>			'db users.timezone|in '.implode(',', array_keys($this->timezones)),
 			'theme' =>				'db users.theme|in '.implode(',', $themes),
@@ -70,13 +71,14 @@ class CControllerUserProfileEdit extends CControllerUserEditGeneral {
 		}
 
 		$users = API::User()->get([
-			'output' => ['alias', 'name', 'surname', 'lang', 'theme', 'autologin', 'autologout', 'refresh',
-				'rows_per_page', 'url', 'timezone'
+			'output' => ['username', 'name', 'surname', 'lang', 'theme', 'autologin', 'autologout', 'refresh',
+				'rows_per_page', 'url', 'timezone', 'userdirectoryid'
 			],
 			'selectMedias' => (CWebUser::$data['type'] > USER_TYPE_ZABBIX_USER)
 				? ['mediatypeid', 'period', 'sendto', 'severity', 'active']
 				: null,
 			'userids' => CWebUser::$data['userid'],
+			'selectUsrgrps' => ['userdirectoryid'],
 			'editable' => true
 		]);
 
@@ -96,10 +98,11 @@ class CControllerUserProfileEdit extends CControllerUserEditGeneral {
 
 		$data = [
 			'userid' => CWebUser::$data['userid'],
-			'alias' => $this->user['alias'],
+			'username' => $this->user['username'],
 			'name' => $this->user['name'],
 			'surname' => $this->user['surname'],
 			'change_password' => $this->hasInput('change_password') || $this->hasInput('password1'),
+			'current_password' => '',
 			'password1' => '',
 			'password2' => '',
 			'lang' => $this->user['lang'],
@@ -116,15 +119,26 @@ class CControllerUserProfileEdit extends CControllerUserEditGeneral {
 			'action' => $this->getAction()
 		];
 
+		$data['internal_auth'] = true;
+
+		foreach ($this->user['usrgrps'] as $group) {
+			if ($group['userdirectoryid'] != 0) {
+				$data['internal_auth'] = false;
+				break;
+			}
+		}
+
 		if (CWebUser::$data['type'] > USER_TYPE_ZABBIX_USER) {
 			$data['medias'] = $this->user['medias'];
 		}
 
 		// Overwrite with input variables.
-		$this->getInputs($data, ['password1', 'password2', 'lang', 'timezone', 'theme', 'autologin', 'autologout',
-			'refresh', 'rows_per_page', 'url', 'form_refresh'
+		$this->getInputs($data, ['current_password', 'password1', 'password2', 'lang', 'timezone', 'theme', 'autologin',
+			'autologout', 'refresh', 'rows_per_page', 'url', 'form_refresh'
 		]);
 
+		$data['password_requirements'] = $this->getPasswordRequirements();
+
 		if (CWebUser::$data['type'] > USER_TYPE_ZABBIX_USER) {
 			if ($data['form_refresh'] != 0) {
 				$data['medias'] = $this->getInput('medias', []);
@@ -133,6 +147,18 @@ class CControllerUserProfileEdit extends CControllerUserEditGeneral {
 			$data = $this->setUserMedias($data);
 		}
 
+		$data['readonly'] = false;
+		$data['userdirectoryid'] = $this->user['userdirectoryid'];
+
+		if ($this->user['userdirectoryid'] != 0) {
+			$data['readonly'] = true;
+		}
+
+		$data['mediatypes'] = API::MediaType()->get([
+			'output' => ['status'],
+			'preservekeys' => true
+		]);
+
 		$response = new CControllerResponseData($data);
 		$response->setTitle(_('User profile'));
 		$this->setResponse($response);
