@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,17 +25,18 @@
 
 $this->includeJsFile('administration.housekeeping.edit.js.php');
 
-$widget = (new CWidget())
+$html_page = (new CHtmlPage())
 	->setTitle(_('Housekeeping'))
-	->setTitleSubmenu(getAdministrationGeneralSubmenu());
+	->setDocUrl(CDocHelper::getUrl(CDocHelper::ADMINISTRATION_HOUSEKEEPING_EDIT));
 
 $form = (new CForm())
+	->addItem((new CVar(CCsrfTokenHelper::CSRF_TOKEN_NAME, CCsrfTokenHelper::get('housekeeping')))->removeId())
 	->setId('housekeeping')
 	->setAction((new CUrl('zabbix.php'))
 		->setArgument('action', 'housekeeping.update')
 		->getUrl()
 	)
-	->setAttribute('aria-labeledby', ZBX_STYLE_PAGE_TITLE);
+	->setAttribute('aria-labelledby', CHtmlPage::PAGE_TITLE_ID);
 
 $house_keeper_tab = (new CFormList())
 	->addRow((new CTag('h4', true, _('Events and alerts')))->addClass('input-section-header'))
@@ -54,6 +55,15 @@ $house_keeper_tab = (new CFormList())
 			->setEnabled($data['hk_events_mode'] == 1)
 			->setAriaRequired()
 	)
+	->addRow(
+		(new CLabel(_('Service data storage period'), 'hk_events_service'))->setAsteriskMark(),
+		(new CTextBox('hk_events_service', $data['hk_events_service'], false,
+			DB::getFieldLength('config', 'hk_events_service')
+		))
+			->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
+			->setEnabled($data['hk_events_mode'] == 1)
+			->setAriaRequired()
+	)
 	->addRow(
 		(new CLabel(_('Internal data storage period'), 'hk_events_internal'))->setAsteriskMark(),
 		(new CTextBox('hk_events_internal', $data['hk_events_internal'], false,
@@ -96,19 +106,6 @@ $house_keeper_tab = (new CFormList())
 			->setEnabled($data['hk_services_mode'] == 1)
 			->setAriaRequired()
 	)
-	->addRow((new CTag('h4', true, _('Audit')))->addClass('input-section-header'))
-	->addRow(
-		new CLabel(_('Enable internal housekeeping'), 'hk_audit_mode'),
-		(new CCheckBox('hk_audit_mode'))->setChecked($data['hk_audit_mode'] == 1)
-	)
-	->addRow(
-		(new CLabel(_('Data storage period'), 'hk_audit'))
-			->setAsteriskMark(),
-		(new CTextBox('hk_audit', $data['hk_audit'], false, DB::getFieldLength('config', 'hk_audit')))
-			->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
-			->setEnabled($data['hk_audit_mode'] == 1)
-			->setAriaRequired()
-	)
 	->addRow((new CTag('h4', true, _('User sessions')))->addClass('input-section-header'))
 	->addRow(
 		new CLabel(_('Enable internal housekeeping'), 'hk_sessions_mode'),
@@ -128,8 +125,17 @@ $house_keeper_tab = (new CFormList())
 		(new CCheckBox('hk_history_mode'))->setChecked($data['hk_history_mode'] == 1)
 	)
 	->addRow(
-		new CLabel(_('Override item history period'), 'hk_history_global'),
-		(new CCheckBox('hk_history_global'))->setChecked($data['hk_history_global'] == 1)
+		new CLabel([
+			_('Override item history period'),
+			array_key_exists(CHousekeepingHelper::OVERRIDE_NEEDED_HISTORY, $data)
+				? makeWarningIcon(
+					_('This setting should be enabled, because history tables contain compressed chunks.')
+				)
+					->addStyle('display:none;')
+					->addClass('js-hk-history-warning')
+				: null
+		], 'hk_history_global'),
+		(new CCheckBox('hk_history_global'))->setChecked($data['hk_history_global'] == 1),
 	)
 	->addRow(
 		(new CLabel(_('Data storage period'), 'hk_history'))
@@ -145,7 +151,14 @@ $house_keeper_tab = (new CFormList())
 		(new CCheckBox('hk_trends_mode'))->setChecked($data['hk_trends_mode'] == 1)
 	)
 	->addRow(
-		new CLabel(_('Override item trend period'), 'hk_trends_global'),
+		new CLabel([
+			_('Override item trend period'),
+			array_key_exists(CHousekeepingHelper::OVERRIDE_NEEDED_TRENDS, $data)
+				? makeWarningIcon(_('This setting should be enabled, because trend tables contain compressed chunks.'))
+					->addStyle('display:none;')
+					->addClass('js-hk-trends-warning')
+				: null
+		], 'hk_trends_global'),
 		(new CCheckBox('hk_trends_global'))->setChecked($data['hk_trends_global'] == 1)
 	)
 	->addRow(
@@ -157,14 +170,58 @@ $house_keeper_tab = (new CFormList())
 			->setAriaRequired()
 	);
 
-	if ($data['db_extension'] == ZBX_DB_EXTENSION_TIMESCALEDB) {
+	if ($data['db_extension'] === ZBX_DB_EXTENSION_TIMESCALEDB) {
+		switch ($data['extension_err_code']) {
+			case ZBX_EXT_ERR_UNDEFINED:
+				$timescaledb_error = _('Unable to retrieve TimescaleDB compression support status.');
+				break;
+
+			case ZBX_TIMESCALEDB_VERSION_FAILED_TO_RETRIEVE:
+				$timescaledb_error = _('Compression is not supported.').' '.
+					_('Unable to retrieve TimescaleDB version.');
+				break;
+
+			case ZBX_TIMESCALEDB_VERSION_LOWER_THAN_MINIMUM:
+				$timescaledb_error = _('Compression is not supported.').' '.
+					_s('Minimum required TimescaleDB version is %1$s.', $data['timescaledb_min_version']);
+				break;
+
+			case ZBX_TIMESCALEDB_VERSION_NOT_SUPPORTED:
+				$timescaledb_error = _s('Unsupported TimescaleDB version. Should be at least %1$s.',
+					$data['timescaledb_min_supported_version']
+				);
+
+				if (!$data['compression_availability']) {
+					$timescaledb_error = _('Compression is not supported.').' '.$timescaledb_error;
+				}
+				break;
+
+			case ZBX_TIMESCALEDB_VERSION_HIGHER_THAN_MAXIMUM:
+				$timescaledb_error = _s('Unsupported TimescaleDB version. Should not be higher than %1$s.',
+					$data['timescaledb_max_version']
+				);
+				break;
+
+			case ZBX_TIMESCALEDB_LICENSE_NOT_COMMUNITY:
+				$timescaledb_error = _('Detected TimescaleDB license does not support compression. Compression is supported in TimescaleDB Community Edition.');
+				break;
+
+			case ZBX_EXT_SUCCEED:
+			default:
+				$timescaledb_error = '';
+		}
+
+		$timescaledb_error = $timescaledb_error !== '' ? makeErrorIcon($timescaledb_error) : null;
+
+		$compression_status_checkbox = (new CCheckBox('compression_status'))
+			->setChecked($data['compression_status'] == 1)
+			->setEnabled($data['compression_availability']);
+
 		$house_keeper_tab
 			->addRow((new CTag('h4', true, _('History and trends compression')))->addClass('input-section-header'))
 			->addRow(
-				new CLabel(_('Enable compression'), 'compression_status'),
-				(new CCheckBox('compression_status'))
-					->setChecked($data['compression_status'] == 1)
-					->setEnabled($data['compression_availability'] == 1)
+				new CLabel([_('Enable compression'), $timescaledb_error], 'compression_status'),
+				$compression_status_checkbox
 			)
 			->addRow(
 				(new CLabel(_('Compress records older than'), 'compress_older'))
@@ -173,24 +230,29 @@ $house_keeper_tab = (new CFormList())
 					DB::getFieldLength('config', 'compress_older')
 				))
 					->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
-					->setEnabled($data['compression_availability'] == 1 && $data['compression_status'] == 1)
+					->setEnabled($data['compression_status'] == 1 && $data['compression_availability'])
 					->setAriaRequired()
 			);
-
-		if ($data['compression_availability'] == 0) {
-			$house_keeper_tab->addRow('',
-				(new CSpan(_('Compression is not available due to incompatible DB version')))->addClass(ZBX_STYLE_RED)
-			);
-		}
 	}
 
-$house_keeper_view = (new CTabView())
-	->addTab('houseKeeper', _('Housekeeping'), $house_keeper_tab)
-	->setFooter(makeFormFooter(
-		new CSubmit('update', _('Update')),
-		[new CButton('resetDefaults', _('Reset defaults'))]
-	));
+if (CWebUser::checkAccess(CRoleHelper::UI_ADMINISTRATION_AUDIT_LOG)) {
+	$house_keeper_tab
+		->addRow((new CTag('h4', true, _('Audit log')))->addClass('input-section-header'))
+		->addRow(
+			new CLink(_('Audit settings'),
+			(new CUrl('zabbix.php'))->setArgument('action', 'audit.settings.edit'))
+		);
+}
 
-$widget
-	->addItem($form->addItem($house_keeper_view))
+$form->addItem(
+	(new CTabView())
+		->addTab('houseKeeper', _('Housekeeping'), $house_keeper_tab)
+		->setFooter(makeFormFooter(
+			new CSubmit('update', _('Update')),
+			[new CButton('resetDefaults', _('Reset defaults'))]
+		))
+);
+
+$html_page
+	->addItem($form)
 	->show();
