@@ -172,8 +172,7 @@ if ($data['change_password']) {
 		$current_password->setAttribute('autofocus', 'autofocus');
 	}
 
-	if ($data['action'] === 'userprofile.edit'
-			|| CWebUser::$data['userid'] == $data['userid'] && CWebUser::$data['roleid'] == USER_TYPE_SUPER_ADMIN) {
+	if (CWebUser::$data['userid'] == $data['userid']) {
 		$user_form_list
 			->addRow((new CLabel(_('Current password'), 'current_password'))->setAsteriskMark(), $current_password);
 	}
@@ -196,8 +195,11 @@ if ($data['change_password']) {
 		->addRow('', _('Password is not mandatory for non internal authentication type.'));
 }
 else {
-	$change_password_enabled = $data['internal_authentication'] && !$data['readonly']
-		&& ($data['action'] === 'userprofile.edit' || $data['db_user']['username'] !== ZBX_GUEST_USER);
+	$change_password_enabled = !$data['readonly'] && $data['internal_auth'];
+
+	if ($change_password_enabled && $data['action'] === 'user.edit') {
+		$change_password_enabled = $data['db_user']['username'] !== ZBX_GUEST_USER;
+	}
 
 	$hint = !$change_password_enabled
 		? $hint = (makeErrorIcon(_('Password can only be changed for users using the internal Zabbix authentication.')))
@@ -300,13 +302,14 @@ if ($data['action'] === 'userprofile.edit' || $data['db_user']['username'] !== Z
 			->setId('autologout_visible')
 			->setChecked($data['autologout'] !== '0'),
 		(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-		(new CTextBox('autologout', $autologout))->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
+		(new CTextBox('autologout', $autologout, false, DB::getFieldLength('users', 'autologout')))
+			->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
 	]);
 }
 
 $user_form_list
 	->addRow((new CLabel(_('Refresh'), 'refresh'))->setAsteriskMark(),
-		(new CTextBox('refresh', $data['refresh']))
+		(new CTextBox('refresh', $data['refresh'], false, DB::getFieldLength('users', 'refresh')))
 			->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
 			->setAriaRequired()
 	)
@@ -405,7 +408,9 @@ if ($data['action'] === 'user.edit' || CWebUser::$data['type'] > USER_TYPE_ZABBI
 							->setEnabled(!$data['readonly'])
 							->addClass(ZBX_STYLE_BTN_LINK)
 							->setAttribute('data-parameters', json_encode($parameters))
-							->onClick('PopUp("popup.media", JSON.parse(this.dataset.parameters));'),
+							->onClick('PopUp("popup.media", JSON.parse(this.dataset.parameters),
+								{dialogue_class: "modal-popup-generic"});'
+							),
 						(new CButton(null, _('Remove')))
 							->setEnabled(!$data['readonly'])
 							->addClass(ZBX_STYLE_BTN_LINK)
@@ -420,7 +425,10 @@ if ($data['action'] === 'user.edit' || CWebUser::$data['type'] > USER_TYPE_ZABBI
 		(new CDiv([
 			$media_table_info,
 			(new CButton(null, _('Add')))
-				->onClick('PopUp("popup.media", '.json_encode(['dstfrm' => $user_form->getName()]).');')
+				->onClick('PopUp("popup.media", '.
+					json_encode(['dstfrm' => $user_form->getName()]).
+					', {dialogue_class: "modal-popup-generic"});'
+				)
 				->addClass(ZBX_STYLE_BTN_LINK)
 				->setEnabled(!$data['readonly'])
 		]))
@@ -465,7 +473,9 @@ if ($data['action'] === 'user.edit') {
 		);
 	}
 	else {
-		$permissions_form_list->addRow(new CLabel(_('Role'), 'roleid_ms'), $role_multiselect);
+		$permissions_form_list->addRow((new CLabel(_('Role'), 'roleid_ms'))->setAsteriskMark($data['roleid_required']),
+			$role_multiselect
+		);
 	}
 
 	if ($data['roleid']) {
@@ -486,7 +496,7 @@ if ($data['action'] === 'user.edit') {
 				if (array_key_exists('grouped', $group_rights) && $group_rights['grouped']) {
 					$group_name = ($groupid == 0)
 						? italic(_('All groups'))
-						: [$group_rights['name'], '&nbsp;', italic('('._('including subgroups').')')];
+						: [$group_rights['name'], NBSP(), italic('('._('including subgroups').')')];
 				}
 				else {
 					$group_name = $group_rights['name'];
@@ -499,7 +509,7 @@ if ($data['action'] === 'user.edit') {
 				if (array_key_exists('grouped', $group_rights) && $group_rights['grouped']) {
 					$group_name = ($groupid == 0)
 						? italic(_('All groups'))
-						: [$group_rights['name'], '&nbsp;', italic('('._('including subgroups').')')];
+						: [$group_rights['name'], NBSP(), italic('('._('including subgroups').')')];
 				}
 				else {
 					$group_name = $group_rights['name'];
