@@ -25,7 +25,6 @@
 
 // Create form.
 $expression_form = (new CForm())
-	->cleanItems()
 	->setName('expression')
 	->addVar('action', 'popup.triggerexpr')
 	->addVar('dstfrm', $data['dstfrm'])
@@ -33,11 +32,10 @@ $expression_form = (new CForm())
 	->addVar('context', $data['context'])
 	->addItem((new CVar('hostid', $data['hostid']))->removeId())
 	->addVar('groupid', $data['groupid'])
-	->addVar('function', $data['function'])
-	->addItem((new CInput('submit', 'submit'))
-		->addStyle('display: none;')
-		->removeId()
-	);
+	->addVar('function', $data['function']);
+
+// Enable form submitting on Enter.
+$expression_form->addItem((new CSubmitButton(null))->addClass(ZBX_STYLE_FORM_SUBMIT_HIDDEN));
 
 if ($data['parent_discoveryid'] !== '') {
 	$expression_form->addVar('parent_discoveryid', $data['parent_discoveryid']);
@@ -82,7 +80,12 @@ if ($data['item_required']) {
 		(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 		(new CButton('select', _('Select')))
 			->addClass(ZBX_STYLE_BTN_GREY)
-			->onClick('return PopUp("popup.generic", '.json_encode($popup_options).');')
+			->onClick(
+				'return PopUp("popup.generic", '.
+					json_encode($popup_options).
+					', {dialogue_class: "modal-popup-generic"}
+				);'
+			)
 	];
 
 	if ($data['parent_discoveryid'] !== '') {
