@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,36 +21,42 @@
 
 /**
  * @var CView $this
+ * @var array $data
  */
 
 require_once dirname(__FILE__).'/js/configuration.item.list.js.php';
 
-$widget = (new CWidget())
+$html_page = (new CHtmlPage())
 	->setTitle(_('Items'))
+	->setDocUrl(CDocHelper::getUrl($data['context'] === 'host'
+		? CDocHelper::DATA_COLLECTION_HOST_ITEM_LIST
+		: CDocHelper::DATA_COLLECTION_TEMPLATE_ITEM_LIST
+	))
 	->setControls(
 		(new CTag('nav', true,
-			(new CList())->addItem(
-				($data['hostid'] != 0)
-					? new CRedirectButton(_('Create item'), (new CUrl('items.php'))
-						->setArgument('form', 'create')
-						->setArgument('hostid', $data['hostid'])
-						->setArgument('context', $data['context'])
-						->getUrl()
-					)
-					: (new CButton('form',
-						($data['context'] === 'host')
-							? _('Create item (select host first)')
-							: _('Create item (select template first)')
-					))->setEnabled(false)
-			)
+			(new CList())
+				->addItem(
+					$data['hostid'] != 0
+						? new CRedirectButton(_('Create item'),
+							(new CUrl('items.php'))
+								->setArgument('form', 'create')
+								->setArgument('hostid', $data['hostid'])
+								->setArgument('context', $data['context'])
+						)
+						: (new CButton('form',
+							$data['context'] === 'host'
+								? _('Create item (select host first)')
+								: _('Create item (select template first)')
+						))->setEnabled(false)
+				)
 		))->setAttribute('aria-label', _('Content controls'))
 	);
 
 if ($data['hostid'] != 0) {
-	$widget->setNavigation(getHostNavigation('items', $data['hostid']));
+	$html_page->setNavigation(getHostNavigation('items', $data['hostid']));
 }
 
-$widget->addItem(new CPartial('configuration.filter.items', [
+$html_page->addItem(new CPartial('configuration.filter.items', [
 	'filter_data' => $data['filter_data'],
 	'subfilter' => $data['subfilter'],
 	'context' => $data['context']
@@ -103,6 +109,7 @@ $data['itemTriggers'] = CMacrosResolverHelper::resolveTriggerExpressions($data['
 ]);
 
 $update_interval_parser = new CUpdateIntervalParser(['usermacros' => true]);
+$csrf_token = CCsrfTokenHelper::get('items.php');
 
 foreach ($data['items'] as $item) {
 	// description
@@ -112,7 +119,7 @@ foreach ($data['items'] as $item) {
 	);
 
 	if (!empty($item['discoveryRule'])) {
-		$description[] = (new CLink(CHtml::encode($item['discoveryRule']['name']),
+		$description[] = (new CLink($item['discoveryRule']['name'],
 			(new CUrl('disc_prototypes.php'))
 				->setArgument('parent_discoveryid', $item['discoveryRule']['itemid'])
 				->setArgument('context', $data['context'])
@@ -124,10 +131,10 @@ foreach ($data['items'] as $item) {
 
 	if ($item['type'] == ITEM_TYPE_DEPENDENT) {
 		if ($item['master_item']['type'] == ITEM_TYPE_HTTPTEST) {
-			$description[] = CHtml::encode($item['master_item']['name']);
+			$description[] = $item['master_item']['name'];
 		}
 		else {
-			$description[] = (new CLink(CHtml::encode($item['master_item']['name']),
+			$description[] = (new CLink($item['master_item']['name'],
 				(new CUrl('items.php'))
 					->setArgument('form', 'update')
 					->setArgument('hostid', $item['hostid'])
@@ -141,7 +148,7 @@ foreach ($data['items'] as $item) {
 		$description[] = NAME_DELIMITER;
 	}
 
-	$description[] = new CLink(CHtml::encode($item['name']),
+	$description[] = new CLink($item['name'],
 		(new CUrl('items.php'))
 			->setArgument('form', 'update')
 			->setArgument('hostid', $item['hostid'])
@@ -160,11 +167,12 @@ foreach ($data['items'] as $item) {
 					: 'item.massdisable'
 				)
 				->setArgument('context', $data['context'])
+				->setArgument('checkbox_hash', $data['checkbox_hash'])
 				->getUrl()
 		))
-		->addClass(ZBX_STYLE_LINK_ACTION)
-		->addClass(itemIndicatorStyle($item['status'], $item['state']))
-		->addSID()
+			->addCsrfToken($csrf_token)
+			->addClass(ZBX_STYLE_LINK_ACTION)
+			->addClass(itemIndicatorStyle($item['status'], $item['state']))
 	);
 
 	// triggers info
@@ -185,7 +193,7 @@ foreach ($data['items'] as $item) {
 		$trigger['hosts'] = zbx_toHash($trigger['hosts'], 'hostid');
 
 		$trigger_description[] = new CLink(
-			CHtml::encode($trigger['description']),
+			$trigger['description'],
 			(new CUrl('triggers.php'))
 				->setArgument('form', 'update')
 				->setArgument('hostid', key($trigger['hosts']))
@@ -230,8 +238,8 @@ foreach ($data['items'] as $item) {
 	}
 
 	$wizard = (new CButton(null))
-		->addClass(ZBX_STYLE_ICON_WZRD_ACTION)
-		->setMenuPopup(CMenuPopupHelper::getItemConfiguration([
+		->addClass(ZBX_STYLE_ICON_WIZARD_ACTION)
+		->setMenuPopup(CMenuPopupHelper::getItem([
 			'itemid' => $item['itemid'],
 			'context' => $data['context'],
 			'backurl' => $backurl
@@ -265,13 +273,20 @@ foreach ($data['items'] as $item) {
 		}
 	}
 
+	$checkbox = new CCheckBox('group_itemid['.$item['itemid'].']', $item['itemid']);
+
+	if (in_array($item['type'], checkNowAllowedTypes())
+			&& $item['status'] == ITEM_STATUS_ACTIVE && $item['hosts'][0]['status'] == HOST_STATUS_MONITORED) {
+		$checkbox->setAttribute('data-actions', 'execute');
+	}
+
 	$itemTable->addRow([
-		new CCheckBox('group_itemid['.$item['itemid'].']', $item['itemid']),
+		$checkbox,
 		$wizard,
 		($data['hostid'] == 0) ? $item['host'] : null,
 		(new CCol($description))->addClass(ZBX_STYLE_WORDBREAK),
 		$triggerInfo,
-		(new CDiv(CHtml::encode($item['key_'])))->addClass(ZBX_STYLE_WORDWRAP),
+		(new CDiv($item['key_']))->addClass(ZBX_STYLE_WORDWRAP),
 		$item['delay'],
 		$item['history'],
 		$item['trends'],
@@ -283,15 +298,17 @@ foreach ($data['items'] as $item) {
 }
 
 $button_list = [
-	'item.massenable' => ['name' => _('Enable'), 'confirm' => _('Enable selected items?')],
-	'item.massdisable' => ['name' => _('Disable'), 'confirm' => _('Disable selected items?')]
+	'item.massenable' => ['name' => _('Enable'), 'confirm' => _('Enable selected items?'), 'csrf_token' => $csrf_token],
+	'item.massdisable' => ['name' => _('Disable'), 'confirm' => _('Disable selected items?'),
+		'csrf_token' => $csrf_token
+	]
 ];
 
 if ($data['context'] === 'host') {
 	$massclearhistory = [
-		'name' => _('Clear history'),
-		'confirm' => _('Delete history of selected items?'),
-		'disabled' => $data['is_template']
+		'name' => _('Clear history and trends'),
+		'confirm' => _('Clear history and trends of selected items?'),
+		'csrf_token' => $csrf_token
 	];
 
 	if ($data['config']['compression_status']) {
@@ -299,17 +316,29 @@ if ($data['context'] === 'host') {
 	}
 
 	$button_list += [
-		'item.masscheck_now' => ['name' => _('Execute now'), 'disabled' => $data['is_template']],
+		'item.masscheck_now' => [
+			'content' => (new CSimpleButton(_('Execute now')))
+				->addClass('js-execute-now')
+				->addClass(ZBX_STYLE_BTN_ALT)
+				->setAttribute('data-required', 'execute')
+		],
 		'item.massclearhistory' => $massclearhistory
 	];
 }
 
 $button_list += [
-	'item.masscopyto' => ['name' => _('Copy')],
+	'item.masscopyto' => [
+		'content' => (new CSimpleButton(_('Copy')))
+			->addClass('js-copy')
+			->addClass(ZBX_STYLE_BTN_ALT)
+			->removeId()
+	],
 	'popup.massupdate.item' => [
 		'content' => (new CButton('', _('Mass update')))
 			->onClick(
-				"openMassupdatePopup('popup.massupdate.item', {}, {
+				"openMassupdatePopup('popup.massupdate.item', {".
+					CCsrfTokenHelper::CSRF_TOKEN_NAME.": '".CCsrfTokenHelper::get('item').
+				"'}, {
 					dialogue_class: 'modal-popup-preprocessing',
 					trigger_element: this
 				});"
@@ -317,19 +346,24 @@ $button_list += [
 			->addClass(ZBX_STYLE_BTN_ALT)
 			->removeAttribute('id')
 	],
-	'item.massdelete' => ['name' => _('Delete'), 'confirm' => _('Delete selected items?')]
+	'item.massdelete' => ['name' => _('Delete'), 'confirm' => _('Delete selected items?'), 'csrf_token' => $csrf_token]
 ];
 
 // Append table to form.
-$itemForm->addItem([$itemTable, $data['paging'], new CActionButtonList('action', 'group_itemid', $button_list,
-	$data['checkbox_hash']
-)]);
+$itemForm->addItem([
+	$itemTable, $data['paging'],
+	new CActionButtonList('action', 'group_itemid', $button_list, $data['checkbox_hash'])
+]);
 
-// Append form to widget.
-$widget->addItem($itemForm);
+$html_page
+	->addItem($itemForm)
+	->show();
 
-$widget->show();
-
-(new CScriptTag('view.init();'))
+(new CScriptTag('
+	view.init('.json_encode([
+		'checkbox_hash' => $data['checkbox_hash'],
+		'checkbox_object' => 'group_itemid'
+	]).');
+'))
 	->setOnDocumentReady()
 	->show();
